@@ -3,6 +3,7 @@ import numpy as np
 import os, sys
 
 
+
 class VlibColumnTransformer:
     def __init__(self, transformers, output="numpy"):
         self.transformers = transformers
@@ -14,7 +15,8 @@ class VlibColumnTransformer:
         self.fitted_transformers = []
         self.output_columns = []
         for name, pipeline, cols in self.transformers:
-            pipeline.fit(X, y, override_cols=cols)
+            X_subset = X[cols]
+            pipeline.fit(X_subset, y)
             self.output_columns.extend(pipeline.get_feature_names(cols))
             self.fitted_transformers.append((name, pipeline, cols))
         return self
@@ -22,16 +24,18 @@ class VlibColumnTransformer:
     def transform(self, X):
         transformed_parts = []
         for name, pipeline, cols in self.fitted_transformers:
-            part = pipeline.transform(X.copy(), override_cols=cols)
+            part = pipeline.transform(X[cols].copy())
             part_np = part.values if isinstance(part, pd.DataFrame) else part
             transformed_parts.append(part_np)
 
         X_out = np.hstack(transformed_parts)
         if self.output == "pandas":
             return pd.DataFrame(X_out, columns=self.output_columns, index=X.index)
-        else:
-            return X_out
+        return X_out
 
     def fit_transform(self, X, y=None):
         self.fit(X, y)
-        return self.transform(X)
\ No newline at end of file
+        return self.transform(X)
+
+    def get_feature_names(self):
+        return self.output_columns
